Index: content/public/browser/client_certificate_delegate.h |
diff --git a/content/public/browser/client_certificate_delegate.h b/content/public/browser/client_certificate_delegate.h |
index d957fd995b3fc26665a5d49cbcae0011642d10c7..93f02826176cc7e12cc5eb1c96a9c6d017f1e625 100644 |
--- a/content/public/browser/client_certificate_delegate.h |
+++ b/content/public/browser/client_certificate_delegate.h |
@@ -8,6 +8,7 @@ |
#include "base/macros.h" |
namespace net { |
+class SSLPrivateKey; |
class X509Certificate; |
} |
@@ -21,10 +22,12 @@ class ClientCertificateDelegate { |
ClientCertificateDelegate() {} |
virtual ~ClientCertificateDelegate() {} |
- // Continue the request with |cert|. |cert| may be nullptr to continue without |
- // supplying a certificate. This decision will be remembered for future |
- // requests to the domain. |
- virtual void ContinueWithCertificate(net::X509Certificate* cert) = 0; |
+ // Continue the request with |cert| and matching |key|. |cert| may be nullptr |
+ // to continue without supplying a certificate. This decision will be |
+ // remembered for future requests to the domain. |
+ virtual void ContinueWithCertificate( |
+ scoped_refptr<net::X509Certificate> cert, |
+ scoped_refptr<net::SSLPrivateKey> key) = 0; |
private: |
DISALLOW_COPY_AND_ASSIGN(ClientCertificateDelegate); |